@@ -8,11 +8,11 @@ function(formula, data, w, index=NULL, ...) {
   ## for our purpose data has to be (re)ordered
   ## by time, then group (but this is cared for just below)
 
-  ## reorder data if needed
-  if(!is.null(index)) {
+  ## reorder data if needed # done already
+  #if(!is.null(index)) {
     #require(plm)
-    data <- plm.data(data, index)
-    }
+  #  data <- plm.data(data, index)
+  #  }
 
   gindex <- data[,1]
   tindex <- data[,2]
